---
title: Make
icon: lucide/sparkle
---

# `make()`

??? note "API Reference"

    ??? note "`make()`"

        ::: zyx.operations.make.make
            handler: python

    ??? note "`amake()`"

        ::: zyx.operations.make.amake
            handler: python
